CsvCodec class
Constructors
- CsvCodec()
Properties
-
decoder
→ Converter<
String, List< List< >String> > -
Returns the decoder of
this, converting fromTtoS.latefinal -
encoder
→ Converter<
List, String> -
Returns the encoder from
StoT.latefinal - hashCode → int
-
The hash code for this object.
no setterinherited
-
inverted
→ Codec<
String, List> -
Inverts
this.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
String encoded) → List -
Decodes
encodeddata.inherited -
encode(
List input) → String -
Encodes
input.inherited -
fuse<
R> (Codec< String, R> other) → Codec<List, R> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited