MappedCsvRowDecoder<T> class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
mapper
→ T? Function(List<String> row)
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bind(Stream<String> stream)
→ Stream<T>
-
Transforms the provided
stream.
override
-
cast<RS, RT>()
→ StreamTransformer<RS, RT>
-
Provides a
StreamTransformer<RS, RT> view of this stream transformer.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited