NullIOSink class

Implemented types
Available extensions

Constructors

NullIOSink()

Properties

done Future<void>
A future that will complete when the consumer closes, or when an error occurs.
no setteroverride
encoding Encoding
The Encoding used when writing strings.
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(List<int> data) → void
Adds byte data to the target consumer, ignoring encoding.
override
addError(Object error, [StackTrace? stackTrace]) → void
Passes the error to the target consumer as an error event.
override
addStream(Stream<List<int>> stream) Future<void>
Adds all elements of the given stream.
override
close() Future<void>
Close the target consumer.
override
flush() Future<void>
Returns a Future that completes once all buffered data is accepted by the underlying StreamConsumer.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withIOSink<T>(Future<T> call(IOSink)) Future<T>

Available on IOSink, provided by the OnIoSink extension

write(Object? object) → void
Converts object to a String by invoking Object.toString and adds the encoding of the result to the target consumer.
override
writeAll(Iterable objects, [String separator = ""]) → void
Iterates over the given objects and writes them in sequence.
override
writeCharCode(int charCode) → void
Writes the character of charCode.
override
writeln([Object? object = ""]) → void
Converts object to a String by invoking Object.toString and writes the result to this, followed by a newline.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited