AsyncJsonWritable class abstract interface

An interface for objects that need fine-grained, asynchronous control over how they are written to a JSON sink.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeJsonAsync(StringSink sink, JsonEncoderCallback encode) Future<void>
Writes the JSON representation of this object directly to the sink. Use encode to safely serialize any nested child objects.

Operators

operator ==(Object other) bool
The equality operator.
inherited