writeJsonAsync abstract method

Future<void> writeJsonAsync(
  1. StringSink sink,
  2. JsonEncoderCallback encode
)

Writes the JSON representation of this object directly to the sink. Use encode to safely serialize any nested child objects.

Implementation

Future<void> writeJsonAsync(StringSink sink, JsonEncoderCallback encode);