JsonlChunkedDecoder class
A Converter that handles chunked string boundaries and parses JSON, dropping nulls along the way. Emits raw dynamic objects.
Constructors
-
JsonlChunkedDecoder({Codec<
Object?, String> jsonCodec = const JsonCodec()}) -
const
Properties
Methods
-
bind(
Stream< String> stream) → Stream -
Transforms the provided
stream.inherited -
cast<
RS, RT> () → Converter< RS, RT> -
Provides a
Converter<RS, RT>view of this stream transformer.inherited -
convert(
String input) → dynamic -
Converts
inputand returns the result of the conversion.inherited -
fuse<
TT> (Converter< dynamic, TT> other) → Converter<String, TT> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startChunkedConversion(
Sink sink) → Sink< String> -
Starts a chunked conversion.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited