JsonlDecoder class

Inheritance

Constructors

JsonlDecoder(Codec<Object?, String> jsonCodec)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
jsonCodec → Codec<Object?, String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<String> stream) → Stream<List>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(String items) → List
Converts input and returns the result of the conversion.
override
fuse<TT>(Converter<List, TT> other) → Converter<String, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<List> sink) → Sink<String>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited