JsonlMappedDecoder<T> class

A Converter that fuses line-splitting directly into JSON mapping, avoiding the stream event overhead of LineSplitterConverter.

Inheritance

Constructors

JsonlMappedDecoder(T? fromJson(dynamic), {bool ignoreExceptions = false, Codec<Object?, String> jsonCodec = const JsonCodec(), void onDone()?})
const

Properties

fromJson → T? Function(dynamic)
final
hashCode int
The hash code for this object.
no setterinherited
ignoreExceptions bool
final
jsonCodec Codec<Object?, String>
final
onDone → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<String> stream) Stream<T>
Transforms the provided stream.
inherited
cast<RS, RT>() Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(String input) → T
Converts input and returns the result of the conversion.
inherited
fuse<TT>(Converter<T, TT> other) Converter<String, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<T> sink) Sink<String>
Starts a chunked conversion.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited