JsonlMapper<T> class

A Converter that parses JSON and maps to a strongly typed model, dropping nulls along the way. Designed to be fused with LineSplitter.

Inheritance

Constructors

JsonlMapper(T? fromJson(dynamic), {bool ignoreExceptions = false})
const

Properties

fromJson → T? Function(dynamic)
final
hashCode int
The hash code for this object.
no setterinherited
ignoreExceptions bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<String> stream) Stream<T>
Transforms the provided stream.
inherited
cast<RS, RT>() Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(String input) → T
Converts input and returns the result of the conversion.
override
fuse<TT>(Converter<T, TT> other) Converter<String, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<T> sink) Sink<String>
Starts a chunked conversion.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited