ScopeTrackingPillarAccessor class

Implemented types
Implementers
Available extensions

Constructors

ScopeTrackingPillarAccessor(PillarEntry entryGetter<T>({PillarKey? key, String? token}))

Properties

entryGetter PillarEntry Function<T>({PillarKey? key, String? token})
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackedDependenciesScope PillarScope?
getter/setter pair

Methods

assisted<T, P>(P parameter, {PillarKey? key, String? token}) → T

Available on PillarAccessor, provided by the OnPillarAccessor extension

get<T>({PillarKey? key, String? token}) → T
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateEntry(PillarEntry requestedEntry) → void
wrapFactory<T>(PillarFactory<T> factory) → ({PillarScope? scope, T value})

Operators

operator ==(Object other) bool
The equality operator.
inherited