stream library

Classes

CompositeEventSink<T>
A composite event sink that forwards events to multiple target sinks.
ExceptionStrategy
Strategy to handle exceptions thrown by downstream sinks in a CompositeEventSink.
LineSplitterConverter
SingleValueCachingStream<T>

Extension Types

StreamWithClose

Exceptions / Errors

CompositeSinkException
An exception thrown when ExceptionStrategy.aggregate is used and child sinks throw exceptions.