CompositeSinkException class

An exception thrown when ExceptionStrategy.aggregate is used and child sinks throw exceptions.

Implemented types

Constructors

CompositeSinkException(List<Object> errors)
Creates a new composite sink exception with the provided errors.

Properties

errors List<Object>
The list of exceptions collected from child sinks.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited