ExceptionStrategy enum

Strategy to handle exceptions thrown by downstream sinks in a CompositeEventSink.

Inheritance
Available extensions

Values

failFast → const ExceptionStrategy

Throws the first exception encountered immediately, halting the dispatch.

swallow → const ExceptionStrategy

Ignores any exceptions thrown by child sinks, continuing to the next sink.

aggregate → const ExceptionStrategy

Collects all exceptions thrown by child sinks and throws a single CompositeSinkError at the end.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ExceptionStrategy>
A constant List of the values in this enum, in order of their declaration.