ExceptionStrategy class abstract

Strategy to handle exceptions thrown by downstream sinks in a CompositeEventSink.

Constructors

ExceptionStrategy()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispatch<T>(Iterable<EventSink<T>> sinks, void action(EventSink<T> sink)) → void
Dispatches the action to the sinks.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

aggregate → const ExceptionStrategy
Collects all exceptions thrown by child sinks and throws a single CompositeSinkException at the end, or the original exception if only one was thrown.
failFast → const ExceptionStrategy
Throws the first exception encountered immediately, halting the dispatch.
swallow → const ExceptionStrategy
Ignores any exceptions thrown by child sinks, continuing to the next sink.