OnStreamOfLists<T> extension

on

Methods

asAccumulating({bool emptyMeansRefresh = false}) Stream<List<T>>

Available on Stream<List<T>>, provided by the OnStreamOfLists extension

Accumulates the lists emitted by this stream into a single list.
flattenToList({bool cancelOnError = true, bool sync = false}) Future<List<T>>

Available on Stream<List<T>>, provided by the OnStreamOfLists extension

Gathers all lists emitted by this stream and flattens them into a single list.
mapLists<R>(List<R> mapper(List<T>), {bool skipMappedToEmpty = true}) Stream<List<R>>

Available on Stream<List<T>>, provided by the OnStreamOfLists extension

Maps each list emitted by this stream using mapper.
whereElements(bool predicate(T)?, {bool skipMappedToEmpty = true}) Stream<List<T>>

Available on Stream<List<T>>, provided by the OnStreamOfLists extension

Filters the elements in each list emitted by this stream using predicate.