asAccumulating method
Accumulates the lists emitted by this stream into a single list.
Note: This yields the same List instance on every event, so consumers should be careful not to hold onto old references if they expect them to remain unchanged, or mutate the list.
Implementation
Stream<List<T>> asAccumulating({bool emptyMeansRefresh = false}) {
if (emptyMeansRefresh) {
return _asAccumulatingWithRefresh();
}
return _asAccumulatingSimple();
}