Flag class
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- long → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- short → String?
-
final
- shortOrLong → String
-
no setter
Methods
-
findAndRemoveFlag(
List< String> args) → FlagFindResult? -
getFlagValue(
List< String> args) → String? -
getOptionalFlagValue(
List< String> args) → OptionalFlagResult -
hasFlag(
List< String> args) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited