FluentJson class
- Available extensions
Constructors
- FluentJson({required dynamic json, List breadCrumbs = const []})
-
const
- FluentJson.decode(String json)
- FluentJson.empty()
-
const
- FluentJson.root(dynamic json)
Properties
- asDateTime → DateTime
-
Available on FluentJson, provided by the OnFluentJson extension
no setter - breadCrumbs → List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- json → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cascading(
List accessors) → FluentJson -
elementAt(
dynamic accessor) → FluentJson? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unbox<
T> () → T -
unboxed<
T> (dynamic accessor) → T -
unboxedElementAt<
T> (dynamic accessor) → T? -
unboxIterable(
) → Iterable< FluentJson> -
unboxMappedList<
T> (T mapper(FluentJson)) → List< T>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
dynamic accessor) → FluentJson