io library
Classes
-
JsonlBatchWriter<
T> - A utility that combines Batcher and an IOSink to efficiently write high-frequency data to a JSONL file in batches.
Extensions
- FileEnsureOpenExtension on File
- Extension on File to provide a method that ensures parent directories exist before opening the file for writing.
- OnFileSystemEntity on FileSystemEntity
- OnFunction on IOSink Function()
- OnIoSink on IOSink