json_encode_async library
Classes
- AsyncJsonWritable
- An interface for objects that need fine-grained, asynchronous control over how they are written to a JSON sink.
- JsonStringEscapingSink
- A proxy StringSink that intercepts writes, safely escapes them for JSON, and forwards the raw escaped characters to an underlying sink.
- LazyJson
- StreamingJsonString
-
Streams a
Stream<String>directly to the JSON sink as a single, properly escaped JSON string.
Functions
-
jsonEncodeAsync(
{required Object? object, StringSink? sink, StringSink sinkProvider()?}) → Future< void>
Typedefs
-
JsonEncoderCallback
= Future<
void> Function(Object? object) - A callback that allows an AsyncJsonWritable to recursively encode its children.