writeJsonAsync abstract method
Writes the JSON representation of this object directly to the sink.
Use encode to safely serialize any nested child objects.
Implementation
Future<void> writeJsonAsync(StringSink sink, JsonEncoderCallback encode);
Writes the JSON representation of this object directly to the sink.
Use encode to safely serialize any nested child objects.
Future<void> writeJsonAsync(StringSink sink, JsonEncoderCallback encode);