Pillar class
- Implemented types
- Available extensions
Constructors
- Pillar()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
assisted<
T, P> (P parameter, {PillarKey? key, String? token}) → T -
Available on PillarAccessor, provided by the OnPillarAccessor extension
-
changeNotifierFor(
PillarScope scope) → PillarListenable -
discard(
PillarScope scope) → void -
get<
T> ({PillarKey? key, String? token}) → T -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register<
T> ({PillarKey? key, String? token, PillarFactory< T> ? factory, PillarPureFactory<T> ? pureFactory, T? instance, PillarScope? scope}) → void -
replace<
T> ({required T instance, required PillarScope scope}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited