PillarEntry class
Constructors
- PillarEntry({required PillarKey key, required PillarFactoryWithScopeTracking factory, Object? value, PillarScope? instanceScope})
Properties
- effectiveScopeIncludingDependencies ↔ PillarScope?
-
getter/setter pair
- factory → PillarFactoryWithScopeTracking
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceScope → PillarScope?
-
final
- isInstance → bool
-
final
- key → PillarKey
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ Object?
-
getter/setter pair
Methods
-
get<
T> () → T -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited