PillarScope class
Constructors
- PillarScope({required String name, required PillarScope parent})
-
const
- PillarScope.global()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
final
- parent → PillarScope?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
child(
String name) → PillarScope -
isOrChildOf(
PillarScope scope) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
chooseLowest(
{PillarScope? left, PillarScope? right}) → PillarScope?