stream library

Classes

CompositeEventSink<T>
A composite event sink that forwards events to multiple target sinks.
LineSplitterConverter
SingleValueCachingStream<T>

Enums

ExceptionStrategy
Strategy to handle exceptions thrown by downstream sinks in a CompositeEventSink.

Extension Types

StreamWithClose

Exceptions / Errors

CompositeSinkError
An error thrown when ExceptionStrategy.aggregate is used and child sinks throw exceptions.