CompositeSinkException class
An exception thrown when ExceptionStrategy.aggregate is used and child sinks throw exceptions.
- Implemented types
Constructors
-
CompositeSinkException(List<
Object> errors) -
Creates a new composite sink exception with the provided
errors.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited