OnStream<T> extension
- on
-
- Stream<
T>
- Stream<
Properties
-
lastOrNull
→ Future<
T?> -
Available on Stream<
Returns the last element of the stream, orT> , provided by the OnStream extensionnullif the stream is empty.no setter
Methods
-
mappedLastOrNull<
R> (R? mapper(T)) → Future< R?> -
Available on Stream<
Maps the elements of the stream to a new typeT> , provided by the OnStream extensionRusingmapper. Tracks the mapped values and returns the last non-null mapped value, ornullif the stream is empty or if all mapped values werenull.