OnStreamOfLists<T> extension
Methods
-
asAccumulating(
{bool emptyMeansRefresh = false}) → Stream< List< T> > -
Available on Stream<
Accumulates the lists emitted by this stream into a single list.List< , provided by the OnStreamOfLists extensionT> > -
flattenToList(
{bool cancelOnError = true, bool sync = false}) → Future< List< T> > -
Available on Stream<
Gathers all lists emitted by this stream and flattens them into a single list.List< , provided by the OnStreamOfLists extensionT> > -
mapLists<
R> (List< R> mapper(List<T> ), {bool skipMappedToEmpty = true}) → Stream<List< R> > -
Available on Stream<
Maps each list emitted by this stream usingList< , provided by the OnStreamOfLists extensionT> >mapper. -
whereElements(
bool predicate(T)?, {bool skipMappedToEmpty = true}) → Stream< List< T> > -
Available on Stream<
Filters the elements in each list emitted by this stream usingList< , provided by the OnStreamOfLists extensionT> >predicate.